@@ -1,4 +1,4 @@
 from .base import CacheBackendProtocol
-from .naive_cache_backend import SimpleCacheBackend
+from .simple_cache_backend import SimpleCacheBackend
 
 __all__ = ["CacheBackendProtocol", "SimpleCacheBackend"]
