@@ -44,6 +44,9 @@ else:
     Router = Any
     State = Any
 
+T = TypeVar("T", bound=BaseModel)
+H = TypeVar("H", bound=HTTPConnection)
+
 ExceptionHandler = Callable[
     [Request, Union[Exception, HTTPException, StarletteHTTPException]], Union[Response, StarletteResponse]
 ]
@@ -53,9 +56,7 @@ LifeCycleHandler = Union[
     Callable[[], Awaitable[Any]],
     Callable[[State], Awaitable[Any]],
 ]
-Guard = Union[
-    Callable[[HTTPConnection, BaseRouteHandler], Awaitable[None]], Callable[[HTTPConnection, BaseRouteHandler], None]
-]
+Guard = Union[Callable[[H, BaseRouteHandler], Awaitable[None]], Callable[[H, BaseRouteHandler], None]]
 Method = Union[Literal["GET"], Literal["POST"], Literal["DELETE"], Literal["PATCH"], Literal["PUT"], Literal["HEAD"]]
 ReservedKwargs = Union[
     Literal["request"],
@@ -90,9 +91,6 @@ class MiddlewareProtocol(Protocol):
         ...
 
 
-T = TypeVar("T", bound=BaseModel)
-
-
 class Partial(Generic[T]):
     _models: Dict[Type[T], Any] = {}
 
